@@ -9,7 +9,9 @@
 #let HAVE_GET_CREDENTIALS_OPENBSD = true
 #let HAVE_GET_CREDENTIALS_FREEBSD = false
 #let HAVE_GETPEEREID = true
-#let HAVE_FDATASYNC = false
+#let HAVE_FDATASYNC = true
 #let HAVE_NETDB_REENTRANT = false
 #let HAVE_GET_CREDENTIALS = HAVE_GET_CREDENTIALS_LINUX || HAVE_GET_CREDENTIALS_NETBSD || HAVE_GET_CREDENTIALS_OPENBSD || HAVE_GET_CREDENTIALS_FREEBSD || HAVE_GETPEEREID
 #let windows=false
+#let android=false
+#let libev_default=false
